Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1096)

Unified Diff: chrome/browser/autofill/autofill_common_unittest.h

Issue 2818033: AutoFill: Aggregate profile data. Remove the AutoFill InfoBar. (Closed)
Patch Set: Comment. Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/autofill/address.cc ('k') | chrome/browser/autofill/autofill_common_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/autofill/autofill_common_unittest.h
diff --git a/chrome/browser/autofill/autofill_common_unittest.h b/chrome/browser/autofill/autofill_common_unittest.h
index eef9210bd084973de298bde490364d29c3bf3ada..fdb965f3a522e8d2992bc1e2fa71e0a77af16737 100644
--- a/chrome/browser/autofill/autofill_common_unittest.h
+++ b/chrome/browser/autofill/autofill_common_unittest.h
@@ -8,10 +8,21 @@
class AutoFillProfile;
class CreditCard;
-// Common utilities shared amongst autofill unit tests.
+namespace webkit_glue {
+class FormField;
+} // namespace webkit_glue
+
+// Common utilities shared amongst AutoFill unit tests.
namespace autofill_unittest {
-// A unit testing utility that is common to a number of the autofill unit
+// Provides a quick way to populate a FormField with c-strings.
+void CreateTestFormField(const char* label,
+ const char* name,
+ const char* value,
+ const char* type,
+ webkit_glue::FormField* field);
+
+// A unit testing utility that is common to a number of the AutoFill unit
// tests. |SetProfileInfo| provides a quick way to populate a profile with
// c-strings.
void SetProfileInfo(AutoFillProfile* profile,
@@ -21,15 +32,14 @@ void SetProfileInfo(AutoFillProfile* profile,
const char* state, const char* zipcode, const char* country,
const char* phone, const char* fax);
-// A unit testing utility that is common to a number of the autofill unit
+// A unit testing utility that is common to a number of the AutoFill unit
// tests. |SetCreditCardInfo| provides a quick way to populate a credit card
// with c-strings.
void SetCreditCardInfo(CreditCard* credit_card,
const char* label, const char* name_on_card, const char* type,
const char* card_number, const char* expiration_month,
- const char* expiration_year, const char* verification_code,
- const char* billing_address, const char* shipping_address);
+ const char* expiration_year, const char* billing_address);
-} // namespace
+} // namespace autofill_unittest
#endif // CHROME_BROWSER_AUTOFILL_AUTOFILL_COMMON_UNITTEST_H_
« no previous file with comments | « chrome/browser/autofill/address.cc ('k') | chrome/browser/autofill/autofill_common_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698